# -*- coding: utf-8 -*-

import collections

from django.conf import settings
from django.apps import AppConfig
from django.utils import six
from django.core.checks import register, Error
from django.utils.translation import ugettext_lazy


class JobOfferAppConfig(AppConfig):
    name = 'job_offers'
    verbose_name = ugettext_lazy('Job Offers and applications')

    def ready(self):
        pass


@register()
def ensure_settings_from_email(app_configs):
    if not hasattr(settings, 'JOB_OFFER_FROM_EMAIL'):
        return [
            Error(
                'No setting JOB_OFFER_FROM_EMAIL is defined, it should be an email as a string',
                id='job_offers.E001',
            ),
        ]
    if (not isinstance(settings.JOB_OFFER_FROM_EMAIL, six.string_types) or
            '@' not in settings.JOB_OFFER_FROM_EMAIL):
        return [
            Error(
                'Setting JOB_OFFER_FROM_EMAIL is not a string or is not an email',
                id='job_offers.E002',
            ),
        ]
    return []


@register()
def ensure_settings_emails(app_configs):
    if not hasattr(settings, 'JOB_OFFER_ADMIN_EMAILS'):
        return [
            Error(
                'No setting JOB_OFFER_ADMIN_EMAILS is defined, it should be a list of emails',
                id='job_offers.E003',
            ),
        ]
    if (not isinstance(settings.JOB_OFFER_ADMIN_EMAILS, collections.Iterable) or
            isinstance(settings.JOB_OFFER_ADMIN_EMAILS, six.string_types)):
        return [
            Error(
                'Setting JOB_OFFER_ADMIN_EMAILS is not a list or a tuple',
                id='job_offers.E004',
            ),
        ]
    errors = [
        Error(
            'Setting JOB_OFFER_ADMIN_EMAILS contains an invalid email',
            hint=email,
            id='job_offers.E004',
        )
        for email in settings.JOB_OFFER_ADMIN_EMAILS
        if email.count('@') != 1
    ]
    return errors
