# -*- coding: utf-8 -*-

import datetime
from faker import Faker
import factory.django

from job_offers.models import JobOffer, RelatedObject


fake = Faker()


class RelatedObjectFactory(factory.django.DjangoModelFactory):
    type = 'contract_type'
    slug = factory.Faker('slug')
    name = factory.Faker('word')

    class Meta:
        model = RelatedObject


class JobOfferFactory(factory.django.DjangoModelFactory):
    weight = 100
    reference = factory.Faker('uuid4')
    slug = factory.Faker('slug')
    title = factory.Faker('paragraph')
    job_description = factory.Faker('paragraph')
    tags = factory.Faker('sentence')
    is_active = True
    date = factory.Faker('date_time_between_dates',
                         datetime_start=datetime.date(2016, 6, 15),
                         datetime_end=datetime.date(2017, 6, 15),
                         )

    @factory.post_generation
    def location(self, create, extracted, **kwargs):
        if not create:
            return
        name = extracted or fake.city()
        ro, created = RelatedObject.objects.get_or_create(slug=name.lower(), type='location', defaults={
            'name': name,
        })
        self.relations.add(ro)

    class Meta:
        model = JobOffer


class ContractTypeFactory(factory.django.DjangoModelFactory):
    type = 'contract_type'
    slug = factory.Faker('slug')
    name = factory.Faker('word')

    class Meta:
        model = RelatedObject


class CategoryFactory(factory.django.DjangoModelFactory):
    type = 'category'
    slug = factory.Faker('slug')
    name = factory.Faker('word')

    class Meta:
        model = RelatedObject
